TITLE 'Radiation and symmetry investigation 360'  
{  ASSUMPTIONS   }
{
All dimensions in meter [m]
All angles in degrees 
}

COORDINATES cartesian3 
VARIABLES        	{ system variables }
Tn
i0
SELECT        			{ method controls }
THREADS = 6
ERRLIM = 0.002
PREFER_STABILITY  = ON
check_tables=off


DEFINITIONS    	{ parameter definitions }
#INCLUDE "/360/conventions.pde"																{ acts as glossary and assigns values to certain constants }													! checked
#INCLUDE "/360/conditions.pde"																	{ stipulates the conditions in which the model opperates }														! checked
#INCLUDE "/calculation-input-files/pde/library.fluidFlow.pde"															{ fluidflow calculations }																	! global files for all models
#INCLUDE "/calculation-input-files/pde/library.fluidProperties.pde"													{ fluid properties for fluid flow calculations }									! global files for all models
#INCLUDE "/360/dimensions.inputs.pde"														{ inputs all parameters used to calculated physical dimensions }											! checked, bit clutered but oky
#INCLUDE "/360/dimensions.calculations.pde"											{ calculates physical dimensions and assigns values to points }											! checked
#INCLUDE "/calculation-input-files/pde/materialProperties.pde"														{ specifies all material properties of the model }							! global files for all models
#INCLUDE "/calculation-input-files/pde/3d/calculations.pde"																{ all calculations of model parameters are preformed here }	! global files for all models
#INCLUDE "/calculation-input-files/pde/boundaryConditions.input.pde"											{ inputs needed to preform boundary condition calculations }		! global files for all models
#INCLUDE "/calculation-input-files/pde/boundaryConditions.calculations.pde"								{ calculations of boundary conditions }
MATERIALS
#INCLUDE "/calculation-input-files/pde/materials.pde"		! global files for all models
INITIAL VALUES
Tn = T_ambient
i0 = 0

EXTRUSION			
#INCLUDE "/360/extrusions.pde"			! checked

 BOUNDARIES
 #INCLUDE "/360/boundaries.pde"			! checked
 
! INITIAL VALUES
EQUATIONS        { PDE's, one for each variable }
Tn: 	div(k*grad(Tn) -qr*bol_rad) + q_gen = rho*cp*dt(Tn)
i0:	div(grad(i0)) = 3*(1 - omega_m)*(i0 - 4*PI*ib(Tn))			{ as calculated in radiation formulation document by AH Kotze ccording to Johan should be multiplied by term beta_m^2} 


TIME 0 TO 80 By 0.001 { if time dependent }
{MONITORS         { show progress }
	FOR T = 0 BY 1 to 10
	!CONTOUR(Tn) PAINTED CONTOURS = 50 ON x=0 PNG
    CONTOUR(Tn) PAINTED CONTOURS = 50 ON y=0  PNG
    CONTOUR(Tn) PAINTED CONTOURS = 50 ON z=0  PNG
	SUMMARY
    	REPORT Qr_freeboard_sidewall AS "radiation on wall"
    	REPORT T_gasRamped  AS "Temperature on surface of burden"
!}
PLOTS            { save result displays }
	FOR T = 0 0.01,0.02,0.05 0.1 1 BY 1 to 80
	!CONTOUR(Tn) PAINTED CONTOURS = 50 ON x=0  PNG
    CONTOUR(Tn) FIXED RANGE = (10, 350) PAINTED CONTOURS = 50 ON y=0  PNG
    CONTOUR(Tn) PAINTED CONTOURS = 50 ON z=8/3  PNG
    CONTOUR(Tn) PAINTED CONTOURS = 50 ON z=4.5  PNG
    HISTORY(Tn) at (0,0,1) (10, 0, 1) PNG
    HISTORY(Tn) at (0, 0, 8/3) (0,0,4.5) PNG
    HISTORY(Qr_freeboard_sidewall) PNG
	transfer(Tn, i0) file="transferR6.dat" 
    SUMMARY
    EXPORT FILE "stages_result.txt"
    	REPORT Qr_freeboard_sidewall AS "radiation on wall in kW"
    	REPORT T_gasRamped  AS "Temperature on surface of burden"
!grid(x, y, z) paintregions

END

